<?xml version="1.0" ?><!DOCTYPE TS><TS language="uk" version="2.1">
<context>
    <name>CountdownTooltip</name>
    <message>
        <location filename="../src/countdown_tooltip.cpp" line="78"/>
        <source>Click the tray icon 
or press the shortcut again to stop recording</source>
        <translation>Натисніть іконку в треї
або натисніть гарячі клавіші ще раз, щоб зупинити запис</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/main_window.cpp" line="76"/>
        <source>Deepin screen recorder</source>
        <translation>Записувач Екрану Deepin</translation>
    </message>
    <message>
        <location filename="../src/main_window.cpp" line="136"/>
        <source>Start recording</source>
        <translation>Розпочати запис</translation>
    </message>
    <message>
        <location filename="../src/main_window.cpp" line="454"/>
        <source>Select area</source>
        <translation>Виберіть область</translation>
    </message>
</context>
<context>
    <name>RecordProcess</name>
    <message>
        <location filename="../src/record_process.cpp" line="229"/>
        <source>deepin-screen-recorder</source>
        <translation>deepin-screen-recorder</translation>
    </message>
    <message>
        <location filename="../src/record_process.cpp" line="291"/>
        <source>View</source>
        <translation>Вид</translation>
    </message>
    <message>
        <location filename="../src/record_process.cpp" line="301"/>
        <source>Recording finished</source>
        <translation>Запис закінчено</translation>
    </message>
    <message>
        <location filename="../src/record_process.cpp" line="302"/>
        <source>Saved to</source>
        <translation>Збережено у</translation>
    </message>
</context>
<context>
    <name>StartTooltip</name>
    <message>
        <location filename="../src/start_tooltip.cpp" line="48"/>
        <source>Click or drag to
select the area to record</source>
        <translation>Натисніть або перетяніть,
щоб вибрати область для запису</translation>
    </message>
</context>
</TS>